@@ -1,11 +1,19 @@
 import logging
-from backend import app
+from celery import Celery
 from wiki import Wiki, WikiParameters
 
 
 logger = logging.getLogger(__name__)
 
 
+#TODO: Make those settings configurable!
+app = Celery(
+        'wikked',
+        broker='amqp://',
+        backend='amqp://',
+        include=['wikked.tasks'])
+
+
 class wiki_session(object):
     def __init__(self, wiki_root):
         self.wiki_root = wiki_root
